FleetError

Enum FleetError 

#[non_exhaustive]
pub enum FleetError { Topology(TopologyError), Request(RequestError), TargetNotFound(HostId), StaleTopology { host: HostId, expected: TopologyRevision, actual: TopologyRevision, }, Cancelled, DeadlineExceeded, Connection { host: HostId, message: String, }, Command { host: HostId, message: String, }, RemoteCommandDetached { host: HostId, reason: &'static str, }, Transfer { source_host: HostId, destination_host: HostId, message: String, }, TransferLifecycle(String), EventSink(String), }
Product-neutral fleet discovery, connection, command, and transfer failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Topology(TopologyError)

Topology contract validation failed.



Request(RequestError)

Request contract validation failed.



TargetNotFound(HostId)

A requested host did not exist in the current snapshot.



StaleTopology

The caller bound work to an obsolete host revision.

Fields

host: HostId

Host whose topology changed.

expected: TopologyRevision

Revision bound by the request or cached connection.

actual: TopologyRevision

Current topology revision.



Cancelled

Cancellation was observed before completion.



DeadlineExceeded

The absolute or per-target deadline elapsed.



Connection

A connection driver failed.

Fields

host: HostId

Failed host.

message: String

Driver-safe diagnostic text.



Command

A command driver failed before returning a process result.

Fields

host: HostId

Failed host.

message: String

Driver-safe diagnostic text.



RemoteCommandDetached

A post-spawn remote command was detached and may still be running.

Fields

host: HostId

Remote target.

reason: &'static str

Cancellation or deadline reason.



Transfer

A file transfer driver failed.

Fields

source_host: HostId

Source host.

destination_host: HostId

Destination host.

message: String

Driver-safe diagnostic text.



TransferLifecycle(String)

Transfer lifecycle accounting was invalid.



EventSink(String)

Event emission failed after the underlying action.