RequestError

Enum RequestError 

#[non_exhaustive]
pub enum RequestError { InvalidProgram, InvalidArgument { index: usize, }, TooManyArguments { count: usize, max: usize, }, InvalidAbsolutePath(PathBuf), InvalidOutputLimit { stream: &'static str, bytes: usize, }, InvalidStdinLimit { bytes: usize, max: usize, }, InvalidTransferLimit { bytes: u64, max: u64, }, DeadlineElapsed, InvalidSha256, }
Invalid fleet command or transfer request.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidProgram

Program was empty, oversized, or contained control characters.



InvalidArgument

One positional argument was invalid.

Fields

index: usize

Invalid argument position.



TooManyArguments

Too many positional arguments were supplied.

Fields

count: usize

Supplied argument count.

max: usize

Maximum accepted count.



InvalidAbsolutePath(PathBuf)

Working or transfer path was not absolute and normalized.



InvalidOutputLimit

Output budget was zero or exceeded the hard ceiling.

Fields

stream: &'static str

Output stream.

bytes: usize

Requested byte limit.



InvalidStdinLimit

Command stdin exceeded the hard ceiling.

Fields

bytes: usize

Supplied stdin bytes.

max: usize

Hard maximum.



InvalidTransferLimit

Transfer byte bound was zero or exceeded the hard ceiling.

Fields

bytes: u64

Requested byte limit.

max: u64

Hard maximum.



DeadlineElapsed

Request deadline was not in the future.



InvalidSha256

Content digest was not lowercase SHA-256.