#[non_exhaustive]pub enum TopologyError {
InvalidEndpointText {
field: &'static str,
},
InvalidPort,
InvalidAbsolutePath(PathBuf),
InvalidHttpEndpoint,
InvalidLabel(String),
DuplicateHost(HostId),
RevisionMismatch,
}Expand description
Invalid host endpoint or topology snapshot.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidEndpointText
Endpoint text was empty, oversized, or contained control characters.
InvalidPort
Port zero is never valid.
InvalidAbsolutePath(PathBuf)
A security-sensitive path was not absolute and normalized.
InvalidHttpEndpoint
HTTP endpoint was not plain HTTP(S) or contained embedded credentials.
InvalidLabel(String)
Label was empty, oversized, or contained control characters.
DuplicateHost(HostId)
Host identity appeared more than once.
RevisionMismatch
Serialized endpoint material did not match its claimed revision.