pub struct ForwardedUnixSocket { /* private fields */ }Expand description
RAII guard over one local-to-remote Unix socket forward.
Implementations
Sourceimpl ForwardedUnixSocket
impl ForwardedUnixSocket
Sourcepub async fn open(
connection: &OpenSshConnection,
host: &HostRecord,
remote_path: impl Into<PathBuf>,
cancellation: &CancellationToken,
) -> FleetResult<Self>
pub async fn open( connection: &OpenSshConnection, host: &HostRecord, remote_path: impl Into<PathBuf>, cancellation: &CancellationToken, ) -> FleetResult<Self>
Opens and secures a local Unix socket forwarding to a remote absolute path.
Sourcepub async fn close(self) -> FleetResult<()>
pub async fn close(self) -> FleetResult<()>
Explicitly closes the forward and removes the local socket.