TransferRequest

Struct TransferRequest 

pub struct TransferRequest { /* private fields */ }
Descriptor-confined transfer request between managed hosts.

Implementations

Source

impl TransferRequest

pub fn new( source_host: HostId, source_path: impl Into<PathBuf>, destination_host: HostId, destination_path: impl Into<PathBuf>, max_bytes: u64, deadline: Timestamp, ) -> Result<Self, RequestError>

Creates a validated bounded transfer request.

pub fn with_expected_source_sha256(self, sha256: impl Into<String>) -> Self

Binds the pre-checked source SHA-256 that the bytes read for send must match.

When set, a transfer implementation must hash the bytes it actually reads for send and reject the transfer before any destination write if the digest has drifted from this pre-checked value.

pub fn expected_source_sha256(&self) -> Option<&str>

Returns the pre-checked source SHA-256 bound at plan time, when present.

pub fn validate_at(&self, now: Timestamp) -> Result<(), RequestError>

Rejects a request whose deadline has elapsed.

pub fn source_host(&self) -> &HostId

Returns the source host.

pub fn source_path(&self) -> &Path

Returns the source absolute path.

pub fn destination_host(&self) -> &HostId

Returns the destination host.

pub fn destination_path(&self) -> &Path

Returns the destination absolute path.

pub const fn max_bytes(&self) -> u64

Returns the maximum accepted byte count.

pub const fn deadline(&self) -> Timestamp

Returns the transfer deadline.